==> openshift-model-miscellaneous-5.10.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/network/operator/v1/OperatorPKISpecFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.network.operator.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class OperatorPKISpecFluentImpl<A extends io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.OperatorPKISpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.OperatorPKISpecFluent<A>{
  public OperatorPKISpecFluentImpl() {
  }
  public OperatorPKISpecFluentImpl(io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.OperatorPKISpec instance) {
    this.withTargetCert(instance.getTargetCert()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.CertSpecBuilder targetCert;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildTargetCert instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.CertSpec getTargetCert() {
    return this.targetCert!=null?this.targetCert.build():null;
  }
  public io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.CertSpec buildTargetCert() {
    return this.targetCert!=null?this.targetCert.build():null;
  }
  public A withTargetCert(io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.CertSpec targetCert) {
    _visitables.get("targetCert").remove(this.targetCert);
    if (targetCert!=null){ this.targetCert= new io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.CertSpecBuilder(targetCert); _visitables.get("targetCert").add(this.targetCert);} return (A) this;
  }
  public java.lang.Boolean hasTargetCert() {
    return this.targetCert != null;
  }
  public A withNewTargetCert(java.lang.String commonName) {
    return (A)withTargetCert(new CertSpec(commonName));
  }
  public io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.OperatorPKISpecFluent.TargetCertNested<A> withNewTargetCert() {
    return new io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.OperatorPKISpecFluentImpl.TargetCertNestedImpl();
  }
  public io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.OperatorPKISpecFluent.TargetCertNested<A> withNewTargetCertLike(io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.CertSpec item) {
    return new io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.OperatorPKISpecFluentImpl.TargetCertNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.OperatorPKISpecFluent.TargetCertNested<A> editTargetCert() {
    return withNewTargetCertLike(getTargetCert());
  }
  public io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.OperatorPKISpecFluent.TargetCertNested<A> editOrNewTargetCert() {
    return withNewTargetCertLike(getTargetCert() != null ? getTargetCert(): new io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.CertSpecBuilder().build());
  }
  public io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.OperatorPKISpecFluent.TargetCertNested<A> editOrNewTargetCertLike(io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.CertSpec item) {
    return withNewTargetCertLike(getTargetCert() != null ? getTargetCert(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    OperatorPKISpecFluentImpl that = (OperatorPKISpecFluentImpl) o;
    if (targetCert != null ? !targetCert.equals(that.targetCert) :that.targetCert != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(targetCert,  additionalProperties,  super.hashCode());
  }
  public class TargetCertNestedImpl<N> extends io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.CertSpecFluentImpl<io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.OperatorPKISpecFluent.TargetCertNested<N>> implements io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.OperatorPKISpecFluent.TargetCertNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    TargetCertNestedImpl(io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.CertSpec item) {
      this.builder = new io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.CertSpecBuilder(this, item);
    }
    TargetCertNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.CertSpecBuilder(this);
    }
    io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.CertSpecBuilder builder;
    public N and() {
      return (N) OperatorPKISpecFluentImpl.this.withTargetCert(builder.build());
    }
    public N endTargetCert() {
      return and();
    }
    
  }
  
}

==> openshift-model-miscellaneous-5.12.1-sources.jar: io/fabric8/openshift/api/model/miscellaneous/network/operator/v1/OperatorPKISpecFluentImpl.java <==
package io.fabric8.openshift.api.model.miscellaneous.network.operator.v1;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public class OperatorPKISpecFluentImpl<A extends io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.OperatorPKISpecFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.OperatorPKISpecFluent<A>{
  public OperatorPKISpecFluentImpl() {
  }
  public OperatorPKISpecFluentImpl(io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.OperatorPKISpec instance) {
    this.withTargetCert(instance.getTargetCert()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.CertSpecBuilder targetCert;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildTargetCert instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.CertSpec getTargetCert() {
    return this.targetCert!=null?this.targetCert.build():null;
  }
  public io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.CertSpec buildTargetCert() {
    return this.targetCert!=null?this.targetCert.build():null;
  }
  public A withTargetCert(io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.CertSpec targetCert) {
    _visitables.get("targetCert").remove(this.targetCert);
    if (targetCert!=null){ this.targetCert= new io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.CertSpecBuilder(targetCert); _visitables.get("targetCert").add(this.targetCert);} return (A) this;
  }
  public java.lang.Boolean hasTargetCert() {
    return this.targetCert != null;
  }
  public A withNewTargetCert(java.lang.String commonName) {
    return (A)withTargetCert(new CertSpec(commonName));
  }
  public io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.OperatorPKISpecFluent.TargetCertNested<A> withNewTargetCert() {
    return new io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.OperatorPKISpecFluentImpl.TargetCertNestedImpl();
  }
  public io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.OperatorPKISpecFluent.TargetCertNested<A> withNewTargetCertLike(io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.CertSpec item) {
    return new io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.OperatorPKISpecFluentImpl.TargetCertNestedImpl(item);
  }
  public io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.OperatorPKISpecFluent.TargetCertNested<A> editTargetCert() {
    return withNewTargetCertLike(getTargetCert());
  }
  public io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.OperatorPKISpecFluent.TargetCertNested<A> editOrNewTargetCert() {
    return withNewTargetCertLike(getTargetCert() != null ? getTargetCert(): new io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.CertSpecBuilder().build());
  }
  public io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.OperatorPKISpecFluent.TargetCertNested<A> editOrNewTargetCertLike(io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.CertSpec item) {
    return withNewTargetCertLike(getTargetCert() != null ? getTargetCert(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    OperatorPKISpecFluentImpl that = (OperatorPKISpecFluentImpl) o;
    if (targetCert != null ? !targetCert.equals(that.targetCert) :that.targetCert != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(targetCert,  additionalProperties,  super.hashCode());
  }
  public class TargetCertNestedImpl<N> extends io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.CertSpecFluentImpl<io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.OperatorPKISpecFluent.TargetCertNested<N>> implements io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.OperatorPKISpecFluent.TargetCertNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    TargetCertNestedImpl(io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.CertSpec item) {
      this.builder = new io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.CertSpecBuilder(this, item);
    }
    TargetCertNestedImpl() {
      this.builder = new io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.CertSpecBuilder(this);
    }
    io.fabric8.openshift.api.model.miscellaneous.network.operator.v1.CertSpecBuilder builder;
    public N and() {
      return (N) OperatorPKISpecFluentImpl.this.withTargetCert(builder.build());
    }
    public N endTargetCert() {
      return and();
    }
    
  }
  
}
